@@ -58,7 +58,7 @@ resize(bitarrayobject *self, Py_ssize_t nbits)
     }
 
     if (newsize == size) {
-        /* the buffer size hasn't changed - bypass everything */
+        /* buffer size hasn't changed - bypass everything */
         self->nbits = nbits;
         return 0;
     }
@@ -210,8 +210,7 @@ copy_n(bitarrayobject *self, Py_ssize_t a,
        bytes using memmove, and copy the remaining few bits individually.
        Note that the order of these two operations matters when copying
        self to self. */
-    if (a % 8 == 0 && b % 8 == 0 && n >= 8)
-    {
+    if (a % 8 == 0 && b % 8 == 0 && n >= 8) {
         const size_t bytes = n / 8;
         const Py_ssize_t bits = BITS(bytes);
 
@@ -248,8 +247,6 @@ delete_n(bitarrayobject *self, Py_ssize_t start, Py_ssize_t n)
 {
     assert(0 <= start && start <= self->nbits);
     assert(0 <= n && n <= self->nbits - start);
-    if (n == 0)
-        return 0;
 
     copy_n(self, start, self, start + n, self->nbits - start - n);
     return resize(self, self->nbits - n);
@@ -261,8 +258,6 @@ insert_n(bitarrayobject *self, Py_ssize_t start, Py_ssize_t n)
 {
     assert(0 <= start && start <= self->nbits);
     assert(n >= 0);
-    if (n == 0)
-        return 0;
 
     if (resize(self, self->nbits + n) < 0)
         return -1;
@@ -373,7 +368,7 @@ count(bitarrayobject *self, int vi, Py_ssize_t start, Py_ssize_t stop)
     return vi ? res : stop - start - res;
 }
 
-/* Return index of first occurrence of vi, -1 when x is not in found.
+/* Return index of first occurrence of vi, and -1 when vi is not found.
    This function never fails. */
 static Py_ssize_t
 findfirst(bitarrayobject *self, int vi, Py_ssize_t start, Py_ssize_t stop)
@@ -454,9 +449,6 @@ extend_bitarray(bitarrayobject *self, bitarrayobject *other)
     const Py_ssize_t self_nbits = self->nbits;
     const Py_ssize_t other_nbits = other->nbits;
 
-    if (other_nbits == 0)
-        return 0;
-
     if (resize(self, self_nbits + other_nbits) < 0)
         return -1;
 
@@ -497,8 +489,6 @@ extend_sequence(bitarrayobject *self, PyObject *sequence)
 
     assert(PySequence_Check(sequence));
     n = PySequence_Size(sequence);
-    if (n == 0)
-        return 0;
 
     if (resize(self, self->nbits + n) < 0)
         return -1;
@@ -1129,10 +1119,10 @@ bitarray_frombytes(bitarrayobject *self, PyObject *bytes)
     Py_ssize_t nbytes;
     Py_ssize_t t, p;
 
-    if (!PyBytes_Check(bytes)) {
-        PyErr_SetString(PyExc_TypeError, "bytes expected");
-        return NULL;
-    }
+    if (!PyBytes_Check(bytes))
+        return PyErr_Format(PyExc_TypeError, "bytes expected, not %s",
+                            Py_TYPE(bytes)->tp_name);
+
     nbytes = PyBytes_GET_SIZE(bytes);
     if (nbytes == 0)
         Py_RETURN_NONE;
@@ -1153,7 +1143,7 @@ bitarray_frombytes(bitarrayobject *self, PyObject *bytes)
     memcpy(self->ob_item + (Py_SIZE(self) - nbytes),
            PyBytes_AS_STRING(bytes), (size_t) nbytes);
 
-    if (delete_n(self, t, p) < 0)
+    if (p && delete_n(self, t, p) < 0)
         return NULL;
     Py_RETURN_NONE;
 }
@@ -1177,7 +1167,7 @@ PyDoc_STRVAR(tobytes_doc,
 \n\
 Return the byte representation of the bitarray.\n\
 When the length of the bitarray is not a multiple of 8, the few remaining\n\
-bits (1..7) are considered to be 0.");
+bits are considered 0.");
 
 
 static PyObject *
@@ -1257,8 +1247,8 @@ PyDoc_STRVAR(tofile_doc,
 "tofile(f, /)\n\
 \n\
 Write the byte representation of the bitarray to the file object f.\n\
-When the length of the bitarray is not a multiple of 8,\n\
-the remaining bits (1..7) are set to 0.");
+When the length of the bitarray is not a multiple of 8, the few remaining\n\
+bits are considered 0.");
 
 
 static PyObject *
@@ -1300,13 +1290,11 @@ bitarray_pack(bitarrayobject *self, PyObject *bytes)
     Py_ssize_t nbytes, i;
     char *data;
 
-    if (!PyBytes_Check(bytes)) {
-        PyErr_SetString(PyExc_TypeError, "bytes expected");
-        return NULL;
-    }
+    if (!PyBytes_Check(bytes))
+        return PyErr_Format(PyExc_TypeError, "bytes expected, not %s",
+                            Py_TYPE(bytes)->tp_name);
+
     nbytes = PyBytes_GET_SIZE(bytes);
-    if (nbytes == 0)
-        Py_RETURN_NONE;
 
     if (resize(self, self->nbits + nbytes) < 0)
         return NULL;
@@ -1555,7 +1543,8 @@ bitarray_contains(bitarrayobject *self, PyObject *value)
     if (bitarray_Check(value))
         return search(self, (bitarrayobject *) value, 0) >= 0;
 
-    PyErr_SetString(PyExc_TypeError, "bitarray or bool expected");
+    PyErr_Format(PyExc_TypeError, "bitarray or bool expected, got %s",
+                 Py_TYPE(value)->tp_name);
     return -1;
 }
 
@@ -2853,8 +2842,7 @@ bitarray_from_index(PyTypeObject *type, PyObject *index, int endian)
         return NULL;
 
     if (nbits < 0) {
-        PyErr_SetString(PyExc_ValueError,
-                        "cannot create bitarray with negative length");
+        PyErr_SetString(PyExc_ValueError, "bitarray length must be >= 0");
         return NULL;
     }
     return newbitarrayobject(type, nbits, endian);
@@ -2896,7 +2884,7 @@ bitarray_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
         unsigned char head = *PyBytes_AS_STRING(initial);
 
         if (head < 32 && head % 16 < 8) {
-            if (endian_str == NULL)  /* no endianness given in argument */
+            if (endian_str == NULL)  /* no endianness provided */
                 endian = head / 16 ? ENDIAN_BIG : ENDIAN_LITTLE;
             return unpickle(type, initial, endian);
         }
@@ -2905,7 +2893,7 @@ bitarray_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     if (bitarray_Check(initial) && endian_str == NULL)
         endian = ((bitarrayobject *) initial)->endian;
 
-    /* leave remaining type dispatch to the extend method */
+    /* leave remaining type dispatch to extend method */
     res = newbitarrayobject(type, 0, endian);
     if (res == NULL)
         return NULL;
